pub struct deploySimpleSwapCall {
pub issuer: Address,
pub defaultHardDepositTimeoutDuration: U256,
pub salt: FixedBytes<32>,
}Expand description
Function with signature deploySimpleSwap(address,uint256,bytes32) and selector 0x15efd8a7.
function deploySimpleSwap(address issuer, uint256 defaultHardDepositTimeoutDuration, bytes32 salt) external returns (address);Fields
issuer: AddressdefaultHardDepositTimeoutDuration: U256salt: FixedBytes<32>Trait Implementations
Sourceimpl Clone for deploySimpleSwapCall
impl Clone for deploySimpleSwapCall
Sourcefn clone(&self) -> deploySimpleSwapCall
fn clone(&self) -> deploySimpleSwapCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for deploySimpleSwapCall
impl Debug for deploySimpleSwapCall
impl Eq for deploySimpleSwapCall
Sourceimpl PartialEq for deploySimpleSwapCall
impl PartialEq for deploySimpleSwapCall
Sourcefn eq(&self, other: &deploySimpleSwapCall) -> bool
fn eq(&self, other: &deploySimpleSwapCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl SolCall for deploySimpleSwapCall
impl SolCall for deploySimpleSwapCall
Sourceconst SIGNATURE: &'static str = "deploySimpleSwap(address,uint256,bytes32)"
const SIGNATURE: &'static str = "deploySimpleSwap(address,uint256,bytes32)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address, Uint<256>, FixedBytes<32>)
type Parameters<'a> = (Address, Uint<256>, FixedBytes<32>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<deploySimpleSwapCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<deploySimpleSwapCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Address,)
type ReturnTuple<'a> = (Address,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<deploySimpleSwapCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<deploySimpleSwapCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for deploySimpleSwapCall