pub struct deploySimpleSwapReturn {
pub _0: Address,
}Expand description
Container type for the return parameters of the deploySimpleSwap(address,uint256,bytes32) function.
Fields
_0: AddressTrait Implementations
Sourceimpl Clone for deploySimpleSwapReturn
impl Clone for deploySimpleSwapReturn
Sourcefn clone(&self) -> deploySimpleSwapReturn
fn clone(&self) -> deploySimpleSwapReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for deploySimpleSwapReturn
impl Debug for deploySimpleSwapReturn
impl Eq for deploySimpleSwapReturn
Sourceimpl PartialEq for deploySimpleSwapReturn
impl PartialEq for deploySimpleSwapReturn
Sourcefn eq(&self, other: &deploySimpleSwapReturn) -> bool
fn eq(&self, other: &deploySimpleSwapReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for deploySimpleSwapReturn