pub struct deployedContractsCall {
pub addr: Address,
}Expand description
Function with signature deployedContracts(address) and selector 0xc70242ad.
function deployedContracts(address addr) external view returns (bool);Fields
addr: AddressTrait Implementations
Sourceimpl Clone for deployedContractsCall
impl Clone for deployedContractsCall
Sourcefn clone(&self) -> deployedContractsCall
fn clone(&self) -> deployedContractsCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for deployedContractsCall
impl Debug for deployedContractsCall
impl Eq for deployedContractsCall
Sourceimpl PartialEq for deployedContractsCall
impl PartialEq for deployedContractsCall
Sourcefn eq(&self, other: &deployedContractsCall) -> bool
fn eq(&self, other: &deployedContractsCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl SolCall for deployedContractsCall
impl SolCall for deployedContractsCall
Sourcetype Parameters<'a> = (Address,)
type Parameters<'a> = (Address,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<deployedContractsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<deployedContractsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Bool,)
type ReturnTuple<'a> = (Bool,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<deployedContractsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<deployedContractsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for deployedContractsCall