pub struct deployedContractsReturn {
pub _0: bool,
}Expand description
Container type for the return parameters of the deployedContracts(address) function.
Fields
_0: boolTrait Implementations
Sourceimpl Clone for deployedContractsReturn
impl Clone for deployedContractsReturn
Sourcefn clone(&self) -> deployedContractsReturn
fn clone(&self) -> deployedContractsReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for deployedContractsReturn
impl Debug for deployedContractsReturn
impl Eq for deployedContractsReturn
Sourceimpl PartialEq for deployedContractsReturn
impl PartialEq for deployedContractsReturn
Sourcefn eq(&self, other: &deployedContractsReturn) -> bool
fn eq(&self, other: &deployedContractsReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for deployedContractsReturn