pub struct masterReturn {
pub _0: Address,
}Expand description
Container type for the return parameters of the master() function.
Fields
_0: AddressTrait Implementations
Sourceimpl Clone for masterReturn
impl Clone for masterReturn
Sourcefn clone(&self) -> masterReturn
fn clone(&self) -> masterReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for masterReturn
impl Debug for masterReturn
impl Eq for masterReturn
Sourceimpl PartialEq for masterReturn
impl PartialEq for masterReturn
Sourcefn eq(&self, other: &masterReturn) -> bool
fn eq(&self, other: &masterReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for masterReturn