IERC20Events

Enum IERC20Events 

pub enum IERC20Events {
    Transfer(Transfer),
    Approval(Approval),
}
Container for all the IERC20 events.

Variants



Transfer(Transfer)



Approval(Approval)

Implementations

Source

impl IERC20Events

pub const SELECTORS: &'static [[u8; 32]]

All the selectors of this enum.

Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.

Prefer using SolInterface methods instead.

pub const VARIANT_NAMES: &'static [&'static str]

The names of the variants in the same order as SELECTORS.

pub const SIGNATURES: &'static [&'static str]

The signatures in the same order as SELECTORS.

pub fn signature_by_selector(selector: [u8; 32]) -> Option<&'static str>

Returns the signature for the given selector, if known.

pub fn name_by_selector(selector: [u8; 32]) -> Option<&'static str>

Returns the enum variant name for the given selector, if known.

Source

impl IERC20Events

pub fn transfer(from: Address, to: Address, value: U256) -> Self

Creates a Transfer event.

event Transfer(address,address,uint256)
pub fn approval(owner: Address, spender: Address, value: U256) -> Self

Creates a Approval event.

event Approval(address,address,uint256)