pub struct allowanceReturn {
pub _0: U256,
}Expand description
Container type for the return parameters of the allowance(address,address) function.
Fields
_0: U256Trait Implementations
Sourceimpl Clone for allowanceReturn
impl Clone for allowanceReturn
Sourcefn clone(&self) -> allowanceReturn
fn clone(&self) -> allowanceReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for allowanceReturn
impl Debug for allowanceReturn
impl Eq for allowanceReturn
Sourceimpl PartialEq for allowanceReturn
impl PartialEq for allowanceReturn
Sourcefn eq(&self, other: &allowanceReturn) -> bool
fn eq(&self, other: &allowanceReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for allowanceReturn