pub struct decimalsReturn {
pub _0: u8,
}Expand description
Container type for the return parameters of the decimals() function.
Fields
_0: u8Trait Implementations
Sourceimpl Clone for decimalsReturn
impl Clone for decimalsReturn
Sourcefn clone(&self) -> decimalsReturn
fn clone(&self) -> decimalsReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for decimalsReturn
impl Debug for decimalsReturn
impl Eq for decimalsReturn
Sourceimpl PartialEq for decimalsReturn
impl PartialEq for decimalsReturn
Sourcefn eq(&self, other: &decimalsReturn) -> bool
fn eq(&self, other: &decimalsReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for decimalsReturn