pub struct nameReturn {
pub _0: String,
}Expand description
Container type for the return parameters of the name() function.
Fields
_0: StringTrait Implementations
Sourceimpl Clone for nameReturn
impl Clone for nameReturn
Sourcefn clone(&self) -> nameReturn
fn clone(&self) -> nameReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for nameReturn
impl Debug for nameReturn
impl Eq for nameReturn
Sourceimpl PartialEq for nameReturn
impl PartialEq for nameReturn
Sourcefn eq(&self, other: &nameReturn) -> bool
fn eq(&self, other: &nameReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for nameReturn