pub struct transferFromReturn {
pub _0: bool,
}Expand description
Container type for the return parameters of the transferFrom(address,address,uint256) function.
Fields
_0: boolTrait Implementations
Sourceimpl Clone for transferFromReturn
impl Clone for transferFromReturn
Sourcefn clone(&self) -> transferFromReturn
fn clone(&self) -> transferFromReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for transferFromReturn
impl Debug for transferFromReturn
impl Eq for transferFromReturn
Sourceimpl PartialEq for transferFromReturn
impl PartialEq for transferFromReturn
Sourcefn eq(&self, other: &transferFromReturn) -> bool
fn eq(&self, other: &transferFromReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for transferFromReturn