pub struct claimCall {
pub proofSegments: Vec<FixedBytes<32>>,
pub proveSegment: FixedBytes<32>,
pub proofSegments2: Vec<FixedBytes<32>>,
pub proveSegment2: FixedBytes<32>,
pub chunkSpan: u64,
pub proofSegments3: Vec<FixedBytes<32>>,
}Expand description
Function with signature claim(bytes32[],bytes32,bytes32[],bytes32,uint64,bytes32[]) and selector 0x82ed88be.
function claim(bytes32[] calldata proofSegments, bytes32 proveSegment, bytes32[] calldata proofSegments2, bytes32 proveSegment2, uint64 chunkSpan, bytes32[] calldata proofSegments3) external;Fields
proofSegments: Vec<FixedBytes<32>>proveSegment: FixedBytes<32>proofSegments2: Vec<FixedBytes<32>>proveSegment2: FixedBytes<32>chunkSpan: u64proofSegments3: Vec<FixedBytes<32>>Trait Implementations
impl Eq for claimCall
Sourceimpl SolCall for claimCall
impl SolCall for claimCall
Sourceconst SIGNATURE: &'static str = "claim(bytes32[],bytes32,bytes32[],bytes32,uint64,bytes32[])"
const SIGNATURE: &'static str = "claim(bytes32[],bytes32,bytes32[],bytes32,uint64,bytes32[])"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Array<FixedBytes<32>>, FixedBytes<32>, Array<FixedBytes<32>>, FixedBytes<32>, Uint<64>, Array<FixedBytes<32>>)
type Parameters<'a> = (Array<FixedBytes<32>>, FixedBytes<32>, Array<FixedBytes<32>>, FixedBytes<32>, Uint<64>, Array<FixedBytes<32>>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<claimCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<claimCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = claimReturn
type Return = claimReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<claimCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<claimCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for claimCall