pub struct currentPhaseClaimReturn {
pub _0: bool,
}Expand description
Container type for the return parameters of the currentPhaseClaim() function.
Fields
_0: boolTrait Implementations
Sourceimpl Clone for currentPhaseClaimReturn
impl Clone for currentPhaseClaimReturn
Sourcefn clone(&self) -> currentPhaseClaimReturn
fn clone(&self) -> currentPhaseClaimReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for currentPhaseClaimReturn
impl Debug for currentPhaseClaimReturn
impl Eq for currentPhaseClaimReturn
Sourceimpl PartialEq for currentPhaseClaimReturn
impl PartialEq for currentPhaseClaimReturn
Sourcefn eq(&self, other: ¤tPhaseClaimReturn) -> bool
fn eq(&self, other: ¤tPhaseClaimReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for currentPhaseClaimReturn