pub struct currentPhaseCommitReturn {
pub _0: bool,
}Expand description
Container type for the return parameters of the currentPhaseCommit() function.
Fields
_0: boolTrait Implementations
Sourceimpl Clone for currentPhaseCommitReturn
impl Clone for currentPhaseCommitReturn
Sourcefn clone(&self) -> currentPhaseCommitReturn
fn clone(&self) -> currentPhaseCommitReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for currentPhaseCommitReturn
impl Debug for currentPhaseCommitReturn
impl Eq for currentPhaseCommitReturn
Sourceimpl PartialEq for currentPhaseCommitReturn
impl PartialEq for currentPhaseCommitReturn
Sourcefn eq(&self, other: ¤tPhaseCommitReturn) -> bool
fn eq(&self, other: ¤tPhaseCommitReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for currentPhaseCommitReturn