pub struct currentPhaseRevealReturn {
pub _0: bool,
}Expand description
Container type for the return parameters of the currentPhaseReveal() function.
Fields
_0: boolTrait Implementations
Sourceimpl Clone for currentPhaseRevealReturn
impl Clone for currentPhaseRevealReturn
Sourcefn clone(&self) -> currentPhaseRevealReturn
fn clone(&self) -> currentPhaseRevealReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for currentPhaseRevealReturn
impl Debug for currentPhaseRevealReturn
impl Eq for currentPhaseRevealReturn
Sourceimpl PartialEq for currentPhaseRevealReturn
impl PartialEq for currentPhaseRevealReturn
Sourcefn eq(&self, other: ¤tPhaseRevealReturn) -> bool
fn eq(&self, other: ¤tPhaseRevealReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for currentPhaseRevealReturn