pub struct isParticipatingInUpcomingRoundCall {
pub overlay: FixedBytes<32>,
pub depth: u8,
}Expand description
Function with signature isParticipatingInUpcomingRound(bytes32,uint8) and selector 0xb78a52a7.
function isParticipatingInUpcomingRound(bytes32 overlay, uint8 depth) external view returns (bool);Fields
overlay: FixedBytes<32>depth: u8Trait Implementations
Sourceimpl Clone for isParticipatingInUpcomingRoundCall
impl Clone for isParticipatingInUpcomingRoundCall
Sourcefn clone(&self) -> isParticipatingInUpcomingRoundCall
fn clone(&self) -> isParticipatingInUpcomingRoundCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Eq for isParticipatingInUpcomingRoundCall
Sourceimpl PartialEq for isParticipatingInUpcomingRoundCall
impl PartialEq for isParticipatingInUpcomingRoundCall
Sourcefn eq(&self, other: &isParticipatingInUpcomingRoundCall) -> bool
fn eq(&self, other: &isParticipatingInUpcomingRoundCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl SolCall for isParticipatingInUpcomingRoundCall
impl SolCall for isParticipatingInUpcomingRoundCall
Sourceconst SIGNATURE: &'static str = "isParticipatingInUpcomingRound(bytes32,uint8)"
const SIGNATURE: &'static str = "isParticipatingInUpcomingRound(bytes32,uint8)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (FixedBytes<32>, Uint<8>)
type Parameters<'a> = (FixedBytes<32>, Uint<8>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<isParticipatingInUpcomingRoundCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<isParticipatingInUpcomingRoundCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Bool,)
type ReturnTuple<'a> = (Bool,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<isParticipatingInUpcomingRoundCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<isParticipatingInUpcomingRoundCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for isParticipatingInUpcomingRoundCall