pub struct isParticipatingInUpcomingRoundReturn {
pub _0: bool,
}Expand description
Container type for the return parameters of the isParticipatingInUpcomingRound(bytes32,uint8) function.
Fields
_0: boolTrait Implementations
Sourceimpl Clone for isParticipatingInUpcomingRoundReturn
impl Clone for isParticipatingInUpcomingRoundReturn
Sourcefn clone(&self) -> isParticipatingInUpcomingRoundReturn
fn clone(&self) -> isParticipatingInUpcomingRoundReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Eq for isParticipatingInUpcomingRoundReturn
Sourceimpl PartialEq for isParticipatingInUpcomingRoundReturn
impl PartialEq for isParticipatingInUpcomingRoundReturn
Sourcefn eq(&self, other: &isParticipatingInUpcomingRoundReturn) -> bool
fn eq(&self, other: &isParticipatingInUpcomingRoundReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for isParticipatingInUpcomingRoundReturn