pub struct isWinnerReturn {
pub _0: bool,
}Expand description
Container type for the return parameters of the isWinner(bytes32) function.
Fields
_0: boolTrait Implementations
Sourceimpl Clone for isWinnerReturn
impl Clone for isWinnerReturn
Sourcefn clone(&self) -> isWinnerReturn
fn clone(&self) -> isWinnerReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for isWinnerReturn
impl Debug for isWinnerReturn
impl Eq for isWinnerReturn
Sourceimpl PartialEq for isWinnerReturn
impl PartialEq for isWinnerReturn
Sourcefn eq(&self, other: &isWinnerReturn) -> bool
fn eq(&self, other: &isWinnerReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for isWinnerReturn