pub struct heightOfAddressReturn {
pub _0: u8,
}Expand description
Container type for the return parameters of the heightOfAddress(address) function.
Fields
_0: u8Trait Implementations
Sourceimpl Clone for heightOfAddressReturn
impl Clone for heightOfAddressReturn
Sourcefn clone(&self) -> heightOfAddressReturn
fn clone(&self) -> heightOfAddressReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for heightOfAddressReturn
impl Debug for heightOfAddressReturn
impl Eq for heightOfAddressReturn
Sourceimpl PartialEq for heightOfAddressReturn
impl PartialEq for heightOfAddressReturn
Sourcefn eq(&self, other: &heightOfAddressReturn) -> bool
fn eq(&self, other: &heightOfAddressReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for heightOfAddressReturn