pub struct nodeEffectiveStakeReturn {
pub _0: U256,
}Expand description
Container type for the return parameters of the nodeEffectiveStake(address) function.
Fields
_0: U256Trait Implementations
Sourceimpl Clone for nodeEffectiveStakeReturn
impl Clone for nodeEffectiveStakeReturn
Sourcefn clone(&self) -> nodeEffectiveStakeReturn
fn clone(&self) -> nodeEffectiveStakeReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for nodeEffectiveStakeReturn
impl Debug for nodeEffectiveStakeReturn
impl Eq for nodeEffectiveStakeReturn
Sourceimpl PartialEq for nodeEffectiveStakeReturn
impl PartialEq for nodeEffectiveStakeReturn
Sourcefn eq(&self, other: &nodeEffectiveStakeReturn) -> bool
fn eq(&self, other: &nodeEffectiveStakeReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for nodeEffectiveStakeReturn