pub struct overlayOfAddressReturn {
pub _0: FixedBytes<32>,
}Expand description
Container type for the return parameters of the overlayOfAddress(address) function.
Fields
_0: FixedBytes<32>Trait Implementations
Sourceimpl Clone for overlayOfAddressReturn
impl Clone for overlayOfAddressReturn
Sourcefn clone(&self) -> overlayOfAddressReturn
fn clone(&self) -> overlayOfAddressReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for overlayOfAddressReturn
impl Debug for overlayOfAddressReturn
impl Eq for overlayOfAddressReturn
Sourceimpl PartialEq for overlayOfAddressReturn
impl PartialEq for overlayOfAddressReturn
Sourcefn eq(&self, other: &overlayOfAddressReturn) -> bool
fn eq(&self, other: &overlayOfAddressReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for overlayOfAddressReturn