IStoragePriceOracleEvents

Enum IStoragePriceOracleEvents 

pub enum IStoragePriceOracleEvents {
    PriceUpdate(PriceUpdate),
    StampPriceUpdateFailed(StampPriceUpdateFailed),
}
Container for all the IStoragePriceOracle events.

Variants



PriceUpdate(PriceUpdate)



StampPriceUpdateFailed(StampPriceUpdateFailed)

Implementations

Source

impl IStoragePriceOracleEvents

pub const SELECTORS: &'static [[u8; 32]]

All the selectors of this enum.

Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.

Prefer using SolInterface methods instead.

pub const VARIANT_NAMES: &'static [&'static str]

The names of the variants in the same order as SELECTORS.

pub const SIGNATURES: &'static [&'static str]

The signatures in the same order as SELECTORS.

pub fn signature_by_selector(selector: [u8; 32]) -> Option<&'static str>

Returns the signature for the given selector, if known.

pub fn name_by_selector(selector: [u8; 32]) -> Option<&'static str>

Returns the enum variant name for the given selector, if known.

Source

impl IStoragePriceOracleEvents

pub fn price_update(price: U256) -> Self

Creates a PriceUpdate event.

event PriceUpdate(uint256)
pub fn stamp_price_update_failed(attempted_price: U256) -> Self

Creates a StampPriceUpdateFailed event.

event StampPriceUpdateFailed(uint256)