pub struct adjustPriceReturn {
pub _0: bool,
}Expand description
Container type for the return parameters of the adjustPrice(uint16) function.
Fields
_0: boolTrait Implementations
Sourceimpl Clone for adjustPriceReturn
impl Clone for adjustPriceReturn
Sourcefn clone(&self) -> adjustPriceReturn
fn clone(&self) -> adjustPriceReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for adjustPriceReturn
impl Debug for adjustPriceReturn
impl Eq for adjustPriceReturn
Sourceimpl PartialEq for adjustPriceReturn
impl PartialEq for adjustPriceReturn
Sourcefn eq(&self, other: &adjustPriceReturn) -> bool
fn eq(&self, other: &adjustPriceReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for adjustPriceReturn