pub struct currentPriceReturn {
pub _0: u32,
}Expand description
Container type for the return parameters of the currentPrice() function.
Fields
_0: u32Trait Implementations
Sourceimpl Clone for currentPriceReturn
impl Clone for currentPriceReturn
Sourcefn clone(&self) -> currentPriceReturn
fn clone(&self) -> currentPriceReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for currentPriceReturn
impl Debug for currentPriceReturn
impl Eq for currentPriceReturn
Sourceimpl PartialEq for currentPriceReturn
impl PartialEq for currentPriceReturn
Sourcefn eq(&self, other: ¤tPriceReturn) -> bool
fn eq(&self, other: ¤tPriceReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for currentPriceReturn