pub struct currentRoundReturn {
pub _0: u64,
}Expand description
Container type for the return parameters of the currentRound() function.
Fields
_0: u64Trait Implementations
Sourceimpl Clone for currentRoundReturn
impl Clone for currentRoundReturn
Sourcefn clone(&self) -> currentRoundReturn
fn clone(&self) -> currentRoundReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for currentRoundReturn
impl Debug for currentRoundReturn
impl Eq for currentRoundReturn
Sourceimpl PartialEq for currentRoundReturn
impl PartialEq for currentRoundReturn
Sourcefn eq(&self, other: ¤tRoundReturn) -> bool
fn eq(&self, other: ¤tRoundReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for currentRoundReturn