pub struct lastAdjustedRoundReturn {
pub _0: u64,
}Expand description
Container type for the return parameters of the lastAdjustedRound() function.
Fields
_0: u64Trait Implementations
Sourceimpl Clone for lastAdjustedRoundReturn
impl Clone for lastAdjustedRoundReturn
Sourcefn clone(&self) -> lastAdjustedRoundReturn
fn clone(&self) -> lastAdjustedRoundReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for lastAdjustedRoundReturn
impl Debug for lastAdjustedRoundReturn
impl Eq for lastAdjustedRoundReturn
Sourceimpl PartialEq for lastAdjustedRoundReturn
impl PartialEq for lastAdjustedRoundReturn
Sourcefn eq(&self, other: &lastAdjustedRoundReturn) -> bool
fn eq(&self, other: &lastAdjustedRoundReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for lastAdjustedRoundReturn