pub struct minimumPriceReturn {
pub _0: u32,
}Expand description
Container type for the return parameters of the minimumPrice() function.
Fields
_0: u32Trait Implementations
Sourceimpl Clone for minimumPriceReturn
impl Clone for minimumPriceReturn
Sourcefn clone(&self) -> minimumPriceReturn
fn clone(&self) -> minimumPriceReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for minimumPriceReturn
impl Debug for minimumPriceReturn
impl Eq for minimumPriceReturn
Sourceimpl PartialEq for minimumPriceReturn
impl PartialEq for minimumPriceReturn
Sourcefn eq(&self, other: &minimumPriceReturn) -> bool
fn eq(&self, other: &minimumPriceReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for minimumPriceReturn