pub struct setPriceReturn {
pub _0: bool,
}Expand description
Container type for the return parameters of the setPrice(uint32) function.
Fields
_0: boolTrait Implementations
Sourceimpl Clone for setPriceReturn
impl Clone for setPriceReturn
Sourcefn clone(&self) -> setPriceReturn
fn clone(&self) -> setPriceReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for setPriceReturn
impl Debug for setPriceReturn
impl Eq for setPriceReturn
Sourceimpl PartialEq for setPriceReturn
impl PartialEq for setPriceReturn
Sourcefn eq(&self, other: &setPriceReturn) -> bool
fn eq(&self, other: &setPriceReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for setPriceReturn