pub struct chequeValueDeductionReturn {
pub _0: U256,
}Expand description
Container type for the return parameters of the chequeValueDeduction() function.
Fields
_0: U256Trait Implementations
Sourceimpl Clone for chequeValueDeductionReturn
impl Clone for chequeValueDeductionReturn
Sourcefn clone(&self) -> chequeValueDeductionReturn
fn clone(&self) -> chequeValueDeductionReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for chequeValueDeductionReturn
impl Debug for chequeValueDeductionReturn
impl Eq for chequeValueDeductionReturn
Sourceimpl PartialEq for chequeValueDeductionReturn
impl PartialEq for chequeValueDeductionReturn
Sourcefn eq(&self, other: &chequeValueDeductionReturn) -> bool
fn eq(&self, other: &chequeValueDeductionReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for chequeValueDeductionReturn