pub struct getPriceReturn {
pub price: U256,
pub chequeValueDeduction: U256,
}Expand description
Container type for the return parameters of the getPrice() function.
Fields
price: U256chequeValueDeduction: U256Trait Implementations
Sourceimpl Clone for getPriceReturn
impl Clone for getPriceReturn
Sourcefn clone(&self) -> getPriceReturn
fn clone(&self) -> getPriceReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getPriceReturn
impl Debug for getPriceReturn
impl Eq for getPriceReturn
Sourceimpl PartialEq for getPriceReturn
impl PartialEq for getPriceReturn
Sourcefn eq(&self, other: &getPriceReturn) -> bool
fn eq(&self, other: &getPriceReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for getPriceReturn