nectar-contracts 0.1.0

Swarm storage incentive contract bindings and addresses
docs.rs failed to build nectar-contracts-0.1.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: nectar-contracts-0.1.1

nectar-contracts

Swarm storage incentive contract bindings and deployed contract addresses for Ethereum Swarm networks.

Part of the nectar workspace, a collection of low-level Ethereum Swarm primitives in Rust. See the workspace README for the full crate list and project context.

Usage

[dependencies]
nectar-contracts = "0.1"

This crate is no_std compatible (default features enable std).

License

AGPL-3.0-or-later. See LICENSE.