pub enum IStoragePriceOracleEvents {
PriceUpdate(PriceUpdate),
StampPriceUpdateFailed(StampPriceUpdateFailed),
}Expand description
Container for all the IStoragePriceOracle events.
Variants
PriceUpdate(PriceUpdate)
StampPriceUpdateFailed(StampPriceUpdateFailed)
Implementations
Sourceimpl IStoragePriceOracleEvents
impl IStoragePriceOracleEvents
Sourcepub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl IStoragePriceOracleEvents
impl IStoragePriceOracleEvents
Sourcepub fn price_update(price: U256) -> Self
pub fn price_update(price: U256) -> Self
Creates a PriceUpdate event.
event PriceUpdate(uint256)Sourcepub fn stamp_price_update_failed(attempted_price: U256) -> Self
pub fn stamp_price_update_failed(attempted_price: U256) -> Self
Creates a StampPriceUpdateFailed event.
event StampPriceUpdateFailed(uint256)Trait Implementations
Sourceimpl Clone for IStoragePriceOracleEvents
impl Clone for IStoragePriceOracleEvents
Sourcefn clone(&self) -> IStoragePriceOracleEvents
fn clone(&self) -> IStoragePriceOracleEvents
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IStoragePriceOracleEvents
impl Debug for IStoragePriceOracleEvents
impl Eq for IStoragePriceOracleEvents
Sourceimpl IntoLogData for IStoragePriceOracleEvents
impl IntoLogData for IStoragePriceOracleEvents
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
Convert into a
LogData object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
Consume and convert into a
LogData object.Sourceimpl PartialEq for IStoragePriceOracleEvents
impl PartialEq for IStoragePriceOracleEvents
Sourcefn eq(&self, other: &IStoragePriceOracleEvents) -> bool
fn eq(&self, other: &IStoragePriceOracleEvents) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl SolEventInterface for IStoragePriceOracleEvents
impl SolEventInterface for IStoragePriceOracleEvents
impl StructuralPartialEq for IStoragePriceOracleEvents