pub enum ISwapPriceOracleEvents {
PriceUpdate(PriceUpdate),
ChequeValueDeductionUpdate(ChequeValueDeductionUpdate),
}Expand description
Container for all the ISwapPriceOracle events.
Variants
PriceUpdate(PriceUpdate)
ChequeValueDeductionUpdate(ChequeValueDeductionUpdate)
Implementations
Sourceimpl ISwapPriceOracleEvents
impl ISwapPriceOracleEvents
Sourcepub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl ISwapPriceOracleEvents
impl ISwapPriceOracleEvents
Sourcepub fn price_update(price: U256) -> Self
pub fn price_update(price: U256) -> Self
Creates a PriceUpdate event.
event PriceUpdate(uint256)Sourcepub fn cheque_value_deduction_update(cheque_value_deduction: U256) -> Self
pub fn cheque_value_deduction_update(cheque_value_deduction: U256) -> Self
Creates a ChequeValueDeductionUpdate event.
event ChequeValueDeductionUpdate(uint256)Trait Implementations
Sourceimpl Clone for ISwapPriceOracleEvents
impl Clone for ISwapPriceOracleEvents
Sourcefn clone(&self) -> ISwapPriceOracleEvents
fn clone(&self) -> ISwapPriceOracleEvents
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ISwapPriceOracleEvents
impl Debug for ISwapPriceOracleEvents
impl Eq for ISwapPriceOracleEvents
Sourceimpl IntoLogData for ISwapPriceOracleEvents
impl IntoLogData for ISwapPriceOracleEvents
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
Convert into a
LogData object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
Consume and convert into a
LogData object.Sourceimpl PartialEq for ISwapPriceOracleEvents
impl PartialEq for ISwapPriceOracleEvents
Sourcefn eq(&self, other: &ISwapPriceOracleEvents) -> bool
fn eq(&self, other: &ISwapPriceOracleEvents) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl SolEventInterface for ISwapPriceOracleEvents
impl SolEventInterface for ISwapPriceOracleEvents
impl StructuralPartialEq for ISwapPriceOracleEvents